//
//  YLPieChartView.h
//  PieTouch
//
//  Created by Kemal Taskin on 10/2/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import <UIKit/UIKit.h>

@protocol YLPieChartDataSource;
@protocol YLPieChartDelegate;

typedef enum {
    kSelectionStyleNoAnimation = 0,
    kSelectionStyleOffsetAnimation
} YLPieChartSelectionStyle;

typedef enum {
    kLabelStylePercentage = 0,          // Show percentage of pie slice
    kLabelStyleValue                    // Show actual value of pie slice
} YLPieChartLabelStyle;

/// View that represents a pie chart. All data is supplied via the YLPieChartDataSource protocol.
@interface YLPieChartView : UIView

/** @name Properties */
/// Background color of the pie chart. Default value is white.
@property (nonatomic, retain) UIColor *pieBackgroundColor;

/// Border color of the pie chart. Default value is nil.
@property (nonatomic, retain) UIColor *pieBorderColor;

/// Background color of the inner circle for donut pie charts. Default value is white.
@property (nonatomic, retain) UIColor *innerPieBackgroundColor;

/// Border color of a single pie slice. Default value is nil.
@property (nonatomic, retain) UIColor *sliceBorderColor;

/// Border color for a selected pie slice. Default value is white.
@property (nonatomic, retain) UIColor *selectedSliceBorderColor;

/// Color of text labels. Default value is white.
@property (nonatomic, retain) UIColor *textColor;

/// Shadow color of text labels. Default value is nil.
@property (nonatomic, retain) UIColor *textShadowColor;

/// Font of text labels. Default value is bold system font of size 12.
@property (nonatomic, retain) UIFont *textFont;

/// Border width of the pie chart. Default value is 0.
@property (nonatomic, assign) NSUInteger pieBorderWidth;

/// Border width of pie slices. Default value is 0.
@property (nonatomic, assign) NSUInteger sliceBorderWidth;

/// Border width of selected pie slice. Default is 2.
@property (nonatomic, assign) NSUInteger selectedSliceBorderWidth;

/// Space between the pie chart and the container view. Default value is 10.
@property (nonatomic, assign) NSUInteger padding;

/// Amount of offset that should be applied to selected pie slices. This value should be smaller than the padding value! Default value is 8.
@property (nonatomic, assign) NSUInteger selectionOffset;

/// Percent of offset that should be subtracted from the radius value to calculate the radius of the inner circle. Default value is 0.
/// This value should be between 0 and 1.
@property (nonatomic, assign) CGFloat innerRadiusOffset;

/// Start angle of pie slices in radians. This value should be between 0 and 360 and will be converted to radians internally!
/// Default value is 270 which is the top center point on the circle.
@property (nonatomic, assign) CGFloat startAngle;

/// Duration of the animations.
@property (nonatomic, assign) CGFloat animationDuration;

/// Selection style. Default value is kSelectionStyleOffsetAnimation.
@property (nonatomic, assign) YLPieChartSelectionStyle selectionStyle;

/// Text label style. Default value is kLabelStylePercentage.
@property (nonatomic, assign) YLPieChartLabelStyle labelStyle;

/// Center point of the pie chart.
@property (nonatomic, readonly) CGPoint center;

/// Boolean value that indicates whether selection is allowed. Default value is YES.
@property (nonatomic, assign) BOOL allowsSelection;

/// Boolean value that indicates whether selections should be animated. Default value is YES.
@property (nonatomic, assign) BOOL animateSelection;

/// Boolean value that indicates whether text labels on pie slices should be displayed. Default value is YES.
@property (nonatomic, assign) BOOL showTextLabels;

/// Number of the selected index or -1 if there's no selection.
@property (nonatomic, assign) NSInteger selectedIndex;

///Reference to the datasource that should be used to request additional information.
@property (nonatomic, assign) IBOutlet NSObject<YLPieChartDataSource> *dataSource;

/// Reference to the delegate that should be informed.
@property (nonatomic, assign) IBOutlet NSObject<YLPieChartDelegate> *delegate;


/** @name Initialization */
/// Initializes a YLPieChartView object and returns it to the caller.
/// @returns An initialized YLPieChartView instance.
/// @param frame Frame of the pie chart view.
- (id)initWithFrame:(CGRect)frame;


/** @name Reload Methods */
/// Reloads the pie chart animated.
- (void)reloadData;

/// Reloads the pie chart.
/// @param animated Boolean value that indicates whether the pie chart should be reloaded animated.
- (void)reloadDataAnimated:(BOOL)animated;


/** @name Pie Slice Methods */
/// Returns the normalized value for a specific pie slice. This value is between 0.0 and 1.0.
/// @returns Value between 0.0 and 1.0.
/// @param index The pie slice index.
- (CGFloat)normalizedValueForSliceAtIndex:(NSInteger)index;


/** @name Selection Methods */
/// Selects a pie slice.
/// @param index The pie slice index.
/// @param animated Boolean value that indicates whether selection should be animated.
- (void)selectSliceAtIndex:(NSInteger)index animated:(BOOL)animated;

/// Deselects a pie slice.
/// @param index The pie slice index.
/// @param animated Boolean value that indicates whether deselection should be animated.
- (void)deselectSliceAtIndex:(NSInteger)index animated:(BOOL)animated;

@end
